==> joytran-0.8.1.tar.bz2: joytran-0.8/src/alloc_values.c <==
int max(int a, int b) { if (a > b) { return a; } else { return b; } }
int min(int a, int b) { if (a < b) { return a; } else { return b; } }

void alloc_values () {
  int i = 0;
  smooth_refresh = 3;
  smooth_algorithm = 0;

  NUM_JOYS = SDL_NumJoysticks();

  joys = (SDL_Joystick**)malloc(NUM_JOYS * sizeof(SDL_Joystick*));
  dev_map = (int*)malloc(NUM_JOYS * sizeof(int));
  cfg_map = (int*)malloc(NUM_JOYS * sizeof(int));

  /* this should be safe, because non joysticks contain 0 axes/hats/buttons */
  int MAX_AXIS = 0, MAX_HAT = 0, MAX_BTN = 0;
  for (i = 0; i < NUM_JOYS; i++) {
    SDL_Joystick *joy = SDL_JoystickOpen(i);
    MAX_AXIS = max(SDL_JoystickNumAxes(joy),MAX_AXIS);
    /* we multiply the number of hats by two, since we treat hats like they are
       two separate axes, even though in SDL they are not; it is merely an
       abstraction */
    MAX_HAT =  max(SDL_JoystickNumHats(joy),MAX_HAT)*2;
    MAX_BTN =  max(SDL_JoystickNumButtons(joy),MAX_BTN);
    SDL_JoystickClose(joy);
  }
  axes = (struct joy_axis **)malloc(NUM_JOYS * sizeof(struct joy_axis *));
  *axes = (struct joy_axis *)malloc(MAX_AXIS * NUM_JOYS * sizeof(struct joy_axis));
  hats = (struct joy_hat **)malloc(NUM_JOYS * sizeof(struct joy_hat *));
  *hats = (struct joy_hat *)malloc(MAX_HAT * NUM_JOYS * sizeof(struct joy_hat));
  btns = (struct joy_button **)malloc(NUM_JOYS * sizeof(struct joy_button *));
  *btns = (struct joy_button *)malloc(MAX_BTN * NUM_JOYS * sizeof(struct joy_button));

  for (i = 0; i < NUM_JOYS; i++) { axes[i] = *axes + (i * MAX_AXIS); }
  for (i = 0; i < NUM_JOYS; i++) { hats[i] = *hats + (i * MAX_HAT); }
  for (i = 0; i < NUM_JOYS; i++) { btns[i] = *btns + (i * MAX_BTN); }
}

void dealloc_values() {
  free(*axes); free(axes);
  free(*hats); free(hats);
  free(*btns); free(btns);
  free(joys);
  free(dev_map);
  free(cfg_map);
}

==> joytran-0.8.7.tar.bz2: joytran-0.8.7/src/alloc_values.c <==
#include "helper_fns.h"
#include "joy_data.h"

void alloc_values() {
  int i = 0;
  smooth_refresh = 3;
  smooth_algorithm = 0;

  NUM_JOYS = SDL_NumJoysticks();

  joys = (SDL_Joystick**)malloc(NUM_JOYS * sizeof(SDL_Joystick*));
  dev_map = (int*)malloc(NUM_JOYS * sizeof(int));
  cfg_map = (int*)malloc(NUM_JOYS * sizeof(int));

  /* this should be safe, because non joysticks contain 0 axes/hats/buttons */
  int MAX_AXIS = 0, MAX_HAT = 0, MAX_BTN = 0;
  for (i = 0; i < NUM_JOYS; i++) {
    SDL_Joystick *joy = SDL_JoystickOpen(i);
    MAX_AXIS = max(SDL_JoystickNumAxes(joy),MAX_AXIS);
    /* we multiply the number of hats by two, since we treat hats like they are
       two separate axes, even though in SDL they are not; it is merely an
       abstraction */
    MAX_HAT =  max(SDL_JoystickNumHats(joy),MAX_HAT)*2;
    MAX_BTN =  max(SDL_JoystickNumButtons(joy),MAX_BTN);
    SDL_JoystickClose(joy);
  }
  axes = (struct joy_axis **)malloc(NUM_JOYS * sizeof(struct joy_axis *));
  *axes = (struct joy_axis *)
    malloc(MAX_AXIS * NUM_JOYS * sizeof(struct joy_axis));
  hats = (struct joy_hat **)malloc(NUM_JOYS * sizeof(struct joy_hat *));
  *hats = (struct joy_hat *)
    malloc(MAX_HAT * NUM_JOYS * sizeof(struct joy_hat));
  btns = (struct joy_button **)malloc(NUM_JOYS * sizeof(struct joy_button *));
  *btns = (struct joy_button *)
    malloc(MAX_BTN * NUM_JOYS * sizeof(struct joy_button));

  for (i = 0; i < NUM_JOYS; i++) { axes[i] = *axes + (i * MAX_AXIS); }
  for (i = 0; i < NUM_JOYS; i++) { hats[i] = *hats + (i * MAX_HAT); }
  for (i = 0; i < NUM_JOYS; i++) { btns[i] = *btns + (i * MAX_BTN); }
}

void dealloc_values() {
  free(*axes); free(axes);
  free(*hats); free(hats);
  free(*btns); free(btns);
  free(joys);
  free(dev_map);
  free(cfg_map);
}
